cmoncrawl.processor.pipeline.router
===================================

.. automodule:: cmoncrawl.processor.pipeline.router

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autoclass:: IRouter
      :members:

   .. autoclass:: Route
      :members:

   .. autoclass:: Router
      :members:
   
   

   
   
   



